"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const execa_1 = tslib_1.__importDefault(require("execa"));
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const listr_1 = tslib_1.__importDefault(require("listr"));
const constants_1 = require("../../constants");
class FrameworkInstall extends command_1.Command {
    async run() {
        const { flags } = this.parse(FrameworkInstall);
        const branch = flags.branch || (await this.resolveBranch());
        if (!fs_1.default.existsSync(path_1.default.resolve(flags.destination))) {
            throw new Error(`Destination path ${flags.destination} does not exist`);
        }
        const tasks = new listr_1.default([
            {
                title: 'Install doc framework',
                task: () => {
                    return new listr_1.default([
                        {
                            title: `Cloning framework branch ${branch} in ${flags.destination}`,
                            task: () => execa_1.default.command(`git clone --branch ${branch} --depth 10 --single-branch ${constants_1.fwRepo} ${constants_1.fwDirName}`, {
                                cwd: flags.destination,
                                env: {
                                    PATH: process.env.PATH
                                }
                            })
                        },
                        {
                            title: 'Installing framework dependencies',
                            task: () => execa_1.default('npm', ['ci'], {
                                cwd: path_1.default.join(flags.destination, constants_1.fwDirName)
                            })
                        }
                    ]);
                }
            }
        ]);
        tasks.run();
    }
    async resolveBranch() {
        const { stdout } = await execa_1.default('git', ['rev-parse', '--abbrev-ref', 'HEAD']);
        if (stdout.match(/^master|\d+-stable$/)) {
            return 'master';
        }
        return 'develop';
    }
}
exports.default = FrameworkInstall;
FrameworkInstall.description = 'Install the documentation framework inside a repo';
FrameworkInstall.flags = {
    help: command_1.flags.help({ char: 'h' }),
    branch: command_1.flags.string({
        char: 'b',
        description: 'The framework branch that should be checked out',
        default: process.env.FRAMEWORK_BRANCH
    }),
    destination: command_1.flags.string({
        char: 'd',
        description: 'The path where the framework should be installed',
        default: constants_1.docPathInRepo
    })
};
