"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const constants_1 = require("../../constants");
const execa = require("execa");
exports.buildRepo = (baseRoot, docVersion, deployPath, repoName) => {
    return execa(`$(npm --prefix ${constants_1.fwDirName} bin)/vuepress`, ['build', '--no-cache', docVersion], {
        shell: true,
        cwd: baseRoot,
        env: {
            REPO_NAME: repoName,
            SITE_BASE: deployPath.endsWith('/') ? deployPath : `${deployPath}/`,
            DOC_DIR: docVersion // TODO rename to LOCAL_PATH
        }
    });
};
class RepoBuild extends command_1.Command {
    async run() {
        const { flags } = this.parse(RepoBuild);
        cli_ux_1.default.action.start(`Building version ${flags.doc_version}`);
        const buildTask = exports.buildRepo(flags.doc_root, flags.doc_version, flags.deploy_path, flags.repo_name);
        buildTask.stderr.pipe(process.stderr);
        buildTask.stdout.pipe(process.stdout);
        await buildTask;
        cli_ux_1.default.action.stop();
    }
}
exports.default = RepoBuild;
RepoBuild.description = 'Build the documentation for the current repository';
RepoBuild.flags = {
    help: command_1.flags.help({ char: 'h' }),
    repo_name: command_1.flags.string({
        char: 'n',
        description: 'The name of the repo (used by Algolia)'
    }),
    deploy_path: command_1.flags.string({
        char: 'd',
        description: 'The path where the local version of the docs will be deployed (e.g. /sdk/js/6/) - env: $DEPLOY_PATH',
        default: process.env.DEPLOY_PATH,
        required: true
    }),
    doc_version: command_1.flags.string({
        char: 'v',
        description: 'The local version of the docs to be linked, relative to the base doc root (e.g. 6/) - env: $DOC_VERSION',
        default: process.env.DOC_VERSION,
        required: true
    }),
    doc_root: command_1.flags.string({
        char: 'b',
        description: 'The local root of the docs',
        default: constants_1.docPathInRepo
    })
};
