"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const execa = require("execa");
exports.deploy = (baseRoot, docVersion, deployPath, s3BucketId) => execa('aws', [
    's3',
    'sync',
    `${docVersion}/.vuepress/dist`,
    `s3://${s3BucketId}${deployPath}`,
    '--delete'
], {
    shell: true,
    cwd: baseRoot
});
class RepoDeploy extends command_1.Command {
    async run() {
        const { flags } = this.parse(RepoDeploy);
        cli_ux_1.default.action.start(`Deploying version ${flags.doc_version}`);
        const deployTask = exports.deploy(flags.base_root, flags.doc_version, flags.deploy_path, flags.s3_bucket);
        deployTask.stderr.pipe(process.stderr);
        deployTask.stdout.pipe(process.stdout);
        await deployTask;
        cli_ux_1.default.action.stop();
    }
}
exports.default = RepoDeploy;
RepoDeploy.description = 'Deploy the docs of the current repository to the AWS S3 bucket';
RepoDeploy.flags = {
    help: command_1.flags.help({ char: 'h' }),
    doc_version: command_1.flags.string({
        char: 'v',
        description: 'The local version of the docs to be linked, relative to the base doc root (e.g. 6/) - env: $DOC_VERSION',
        default: process.env.DOC_VERSION,
        required: true
    }),
    deploy_path: command_1.flags.string({
        char: 'd',
        description: 'The path where the local version of the docs will be deployed (e.g. /sdk/js/6/) - env: $DEPLOY_PATH',
        default: process.env.DEPLOY_PATH,
        required: true
    }),
    s3_bucket: command_1.flags.string({
        description: 'The ID of the S3 bucket to deploy the docs to  - env: $S3_BUCKET',
        required: true,
        default: process.env.S3_BUCKET
    }),
    base_root: command_1.flags.string({
        char: 'b',
        description: 'The local root of the docs',
        default: 'doc/'
    })
};
