"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const express_1 = tslib_1.__importDefault(require("express"));
const path_1 = tslib_1.__importDefault(require("path"));
class RepoServe extends command_1.Command {
    async run() {
        const { flags } = this.parse(RepoServe);
        const app = express_1.default();
        const files = path_1.default.resolve(flags.base_root, flags.doc_version, '.vuepress', 'dist');
        app.use(flags.deploy_path, express_1.default.static(files));
        this.log(`Serving files in ${files} on http://localhost:${flags.port}${flags.deploy_path}`);
        app.listen(flags.port);
    }
}
exports.default = RepoServe;
RepoServe.description = 'Serve the docs build of the current repository via a local static http server';
RepoServe.flags = {
    help: command_1.flags.help({ char: 'h' }),
    doc_version: command_1.flags.string({
        char: 'v',
        description: 'The local version of the docs to be linked, relative to the base doc root (e.g. 6/) - env: $DOC_VERSION',
        default: process.env.DOC_VERSION,
        required: true
    }),
    deploy_path: command_1.flags.string({
        char: 'd',
        description: 'The path where the local version of the docs will be deployed (e.g. /sdk/js/6/) - env: $DEPLOY_PATH',
        default: process.env.DEPLOY_PATH,
        parse: input => (input.endsWith('/') ? input : `${input}/`),
        required: true
    }),
    base_root: command_1.flags.string({
        char: 'b',
        description: 'The local root of the docs',
        default: 'doc/'
    }),
    port: command_1.flags.integer({
        char: 'p',
        description: 'The port to open to the static file server',
        default: 3000
    })
};
